Introduction
============


.. image:: https://readthedocs.org/projects/adafruit-board-toolkit/badge/?version=latest
    :target: https://circuitpython.readthedocs.io/projects/board-toolkit/en/latest/
    :alt: Documentation Status


.. image:: https://img.shields.io/discord/327254708534116352.svg
    :target: https://adafru.it/discord
    :alt: Discord


.. image:: https://github.com/adafruit/Adafruit_Board_Toolkit/workflows/Build%20CI/badge.svg
    :target: https://github.com/adafruit/Adafruit_Board_Toolkit/actions
    :alt: Build Status


.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
    :target: https://github.com/psf/black
    :alt: Code Style: Black

CircuitPython board identification and information


Installing from PyPI
=====================
On supported GNU/Linux systems like the Raspberry Pi, you can install the driver locally `from
PyPI <https://pypi.org/project/adafruit-board-toolkit/>`_.
To install for current user:

.. code-block:: shell

    pip3 install adafruit-board-toolkit

To install system-wide (this may be required in some cases):

.. code-block:: shell

    sudo pip3 install adafruit-board-toolkit

To install in a virtual environment in your current project:

.. code-block:: shell

    mkdir project-name && cd project-name
    python3 -m venv .env
    source .env/bin/activate
    pip3 install adafruit-board-toolkit


Contributing
============

Contributions are welcome! Please read our `Code of Conduct
<https://github.com/adafruit/Adafruit_Board_Toolkit/blob/main/CODE_OF_CONDUCT.md>`_
before contributing to help this project stay welcoming.
